@@ -106,8 +106,6 @@ class Site:
 
     def _is_unique(self, filepath: Path, page: Page) -> bool:
         """Checks content if changes are present"""
-        if page.always_refresh:
-            return True
 
         if not filepath.exists():
             return True
@@ -159,7 +157,7 @@ class Site:
 
     def _render_subcollections(self):
         """Generate subcollection pages to be added to routes"""
-        for _, collection in self.collections.items():
+        for collection in self.collections.values():
 
             if collection.subcollections:
 
